psychopy_ext.exp.Task.create_trial — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.create_trial

`Task.` `create_trial`()

  Create a list of events that constitute a trial (`self.trial`).

  Example:

      self.trial = [exp.Event(self,
                              dur=.100,
                              display=self.s['fix'],
                              func=self.idle_event),
                    exp.Event(self,
                              dur=.300,
                              display=self.s['stim1'],
                              func=self.during_trial),
                     ]